@@ -71,6 +71,7 @@ final class UrlAutolinkParserTest extends TestCase
         yield ['(www.google.com/search?q=Markup+(business)', '<p>(<a href="http://www.google.com/search?q=Markup+(business)">www.google.com/search?q=Markup+(business)</a></p>'];
         yield ['www.google.com/search?q=(business))+ok', '<p><a href="http://www.google.com/search?q=(business))+ok">www.google.com/search?q=(business))+ok</a></p>'];
         yield ['(https://www.example.com/test).', '<p>(<a href="https://www.example.com/test">https://www.example.com/test</a>).</p>'];
+        yield ['WWW text followed by a [link](https://example.com/foo-bar-test)', '<p>WWW text followed by a <a href="https://example.com/foo-bar-test">link</a></p>'];
 
         // Tests involving semi-colon endings
         yield ['www.google.com/search?q=commonmark&hl=en', '<p><a href="http://www.google.com/search?q=commonmark&amp;hl=en">www.google.com/search?q=commonmark&amp;hl=en</a></p>'];
@@ -108,4 +109,54 @@ final class UrlAutolinkParserTest extends TestCase
             $html
         );
     }
+
+    public function testDisallowedProtocols(): void
+    {
+        $environment = new Environment([
+            'autolink' => [
+                'allowed_protocols' => ['https'],
+            ],
+        ]);
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addExtension(new AutolinkExtension());
+
+        $converter = new MarkdownConverter($environment);
+        $html      = $converter->convert('http://insecure.example.com')->getContent();
+
+        $this->assertSame("<p>http://insecure.example.com</p>\n", $html);
+    }
+
+    /**
+     * @dataProvider dataProviderForSchemes
+     */
+    public function testUrlAutolinksWithConfigurableSchemes(string $scheme): void
+    {
+        $markdown = 'www.example.com';
+
+        $environment = new Environment([
+            'autolink' => [
+                'default_protocol' => $scheme,
+            ],
+        ]);
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addExtension(new AutolinkExtension());
+
+        $converter = new MarkdownConverter($environment);
+        $html      = $converter->convert($markdown)->getContent();
+
+        $this->assertSame(
+            '<p><a href="' . $scheme . '://www.example.com">www.example.com</a></p>' . "\n",
+            $html
+        );
+    }
+
+    /**
+     * @return iterable<array<string>>
+     */
+    public function dataProviderForSchemes(): iterable
+    {
+        yield ['http'];
+        yield ['https'];
+        yield ['ftp'];
+    }
 }
